@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,17 +13,15 @@ TransportAbstractPlugin::TransportAbstractPlugin(QObject *parent)
 {
 }
 
-TransportAbstractPlugin::~TransportAbstractPlugin()
-{
-}
+TransportAbstractPlugin::~TransportAbstractPlugin() = default;
 
 void TransportAbstractPlugin::cleanUp(MailTransport::Transport *t)
 {
-    Q_UNUSED(t);
+    Q_UNUSED(t)
 }
 
 void TransportAbstractPlugin::initializeTransport(MailTransport::Transport *t, const QString &identifier)
 {
-    Q_UNUSED(identifier);
-    Q_UNUSED(t);
+    Q_UNUSED(identifier)
+    Q_UNUSED(t)
 }
